@@ -4,7 +4,7 @@ import re
 import sys
 from collections import defaultdict
 
-__version__ = "0.0.7"
+__version__ = "0.1.0"
 
 if sys.platform != "win32":
     import signal
@@ -26,7 +26,7 @@ def is_float(value) -> bool:
         return False
 
 
-def get_stats(file, header, column):
+def get_stats(file, header: bool, column: int):
     row = next(file).strip().split("\t")
     if header:
         samples = [row[column - 1]] if column else row
@@ -74,7 +74,7 @@ def get_stats(file, header, column):
     yield "std   \t" + "\t".join(map(str, [stats[sample][5] for sample in samples]))
 
 
-def get_view(file, limit, nlines):
+def get_view(file, limit: int, nlines: int):
     rows = []
     width = []
     for i, line in enumerate(file, start=1):
@@ -97,48 +97,38 @@ def get_view(file, limit, nlines):
         yield "  ".join(out_row)
 
 
-def get_pattern(file, pattern, header, column):
+def get_pattern(file, pattern: str, header: bool):
     if header:
         yield next(file).strip()
-    if pattern.startswith("$"):
-        column = re.match("^\$(\d+)", pattern).group(1)
-        pattern = re.sub("^\$\d+", "x_o_x", pattern)
-        for line in file:
-            try:
-                x_o_x = float(line.strip().split("\t")[int(column) - 1])
-                if eval(pattern):
-                    yield line.strip()
-            except ValueError:
-                pass
-    else:
-        pattern = re.compile(pattern)
-        for line in file:
-            row = line.strip().split("\t")
-            if column:
-                if pattern.match(row[column - 1]):
-                    yield line.strip()
-            else:
-                for value in row:
-                    if pattern.match(value):
-                        yield line.strip()
-                        break
+    for line in file:
+        row = line.strip().split("\t")
+        p = re.findall("\$(\d+)", pattern)
+        columns = [int(i) - 1 for i in p]
+        exp = pattern
+        try:
+            for i in columns:
+                exp = re.sub("\$\d+", f"row[{i}]", exp, 1)
+            if eval(exp):
+                yield line.strip()
+        except ValueError:
+            pass
 
 
 def main():
-    parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter, description="TSV toolkit v{}".format(__version__))
+    parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter, description="TSV toolkit {}".format(__version__))
     parser.add_argument("input", nargs="?", type=argparse.FileType("r"), default=sys.stdin, help="file to parse, tab-delimited, default: stdin")
     parser.add_argument("-H", "--header", action="store_true", help="print header or include header in the output")
     parser.add_argument("-v", "--view", action="store_true", help="aligned display of each column")
     parser.add_argument("-s", "--stat", action="store_true", help="descriptive statistics")
     parser.add_argument("-p", "--pattern", type=str, help="pattern to match, wrap in single quotes")
-    parser.add_argument("-l", "--limit", type=int, default=100, help="limit of column width, used with -v, default 100")
-    parser.add_argument("-n", "--nlines", type=int, default=100, help="max number of lines to view, used with -v, default 100")
-    parser.add_argument("-c", "--column", type=int, default=0, help="column number to match (1-based), used with -s or -p, default all columns")
-    parser.add_argument("-V", "--version", action="version", version=f"v{__version__}")
+    parser.add_argument("-l", "--limit", type=int, default=100, help="limit of column width, used with -v, default: 100")
+    parser.add_argument("-n", "--nlines", type=int, default=100, help="max number of lines to view, used with -v, default: 100")
+    parser.add_argument("-c", "--column", type=int, default=0, help="column number to match (1-based), used with -s, default: 0, means all columns")
+    parser.add_argument("-V", "--version", action="version", version=__version__)
     args = parser.parse_args()
     file = args.input
     if args.pattern:
-        file = get_pattern(file, args.pattern, args.header, args.column)
+        file = get_pattern(file, args.pattern, args.header)
     if args.stat:
         file = get_stats(file, args.header, args.column)
     if args.view:
